@@ -16,9 +16,7 @@ limitations under the License.
 package commands
 
 import (
-	"fmt"
-	"os"
-
+	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
 
@@ -30,15 +28,14 @@ var validationMode string
 var rootCmd = &cobra.Command{
 	Use:   "config-tool",
 	Short: "A Configuration Validation Tool for Quay",
-	Long:  `This tool allows Quay users to validate their configuration bundles11`,
+	Long:  `This tool allows Quay users to validate their configuration bundles.`,
 }
 
 // Execute adds all child commands to the root command and sets flags appropriately.
 // This is called by main.main(). It only needs to happen once to the rootCmd.
 func Execute() {
 	if err := rootCmd.Execute(); err != nil {
-		fmt.Println(err)
-		os.Exit(1)
+		log.Fatalf(err.Error())
 	}
 }
 
